@@ -5,6 +5,9 @@ def google_maps_link(type='hybrid', link=default_link):
     '''
     Returns a function for generating links to Google Maps.
 
+    :param type: map type, one of  'map', 'satellite', or 'hybrid'
+    :param link: Link-generating function; defaults to :func:`~.default_link`
+
     >>> from .tools import MapLink
     >>> google_maps_link()(MapLink("CN Tower", "43.6426", "-79.3871"))
     u'<a href="http://maps.google.com/maps?q=43.6426%2C-79.3871+%28CN+Tower%29&ll=43.6426%2C-79.3871&t=h" title="CN Tower (43.6426, -79.3871)">CN Tower</a>'
